# BLM-AgrR (Blackbird Language Matrices Subject-Verb agreement in Romanian)

**Authors:**  
Vivi Nastase 1, Paola Merlo 1,2

1 Idiap Research Institute, Martigny, Switzerland

2 Department of Linguistics, University of Geneva, Switzerland


**Project / Funding:**  
DISLING/ Disentangling Linguistic Intelligence SNF Advanced grant  TMAG-1_209426 to PM

**Language:**  
Romanian

**Size:**  
22M

**Dataset Type:**  
Synthetic dataset for subject-verb agreement

**Keywords:**  
language intelligence test, synthetic data, subject-verb agreement
---

## Dataset Description

### Overview
**BLM-AgrR** is a dataset in Romanian for learning the underlying rules of subject-verb agreement in sentences, developed in the **Blackbird Language Matrices** (**BLM**) framework.

**BLM-AgrR** is the Romanian version of **BLM-AgrF** (but not an exact translation).

---

### Blackbird Language Matrices (BLM) Task

BLM tasks are framed as **multiple-choice problems**. Given a context of sentences, each built using specific underlying rules, the goal is to predict the next correct sentence from a set of possible answers. Each answer set consists of one correct answer and multiple incorrect (contrastive) options. Incorrect options are generated by introducing variations that violate the underlying generative rules.


---

### Data Splits
BLM datasets also have a lexical variation dimension, to explore the impact of lexical variation on detecting relevant structures: 

- type I – minimal lexical variation for sentences within an instance, 
- type II – one word difference across the sentences within an instance, 
- type III – maximal lexical variation within an instance.

The data comes grouped by **lexical variation** 
(i.e. type I/II/III) and each subset is split into **train**/**test**. 
The statistics of the current iteration of the dataset (v2.0) are (train:test split information)

- **Type I**: 2052 training samples, 230 test samples.
- **Type II**: 5000 training samples, 4571 test samples.
- **Type III**: 5000 training samples, 4571 test samples.

---



### Dataset Structure

The dataset is structured into CSV files, with the following columns:

- **ID**: A unique identifier for the instance.
- **Sent_{n}**: Sentences representing the context (`n` from 1 to 7).
- **Sent_template_{n}**: Chunk pattern of the sentence.
- **Sent_chunks_{n}**: The list of chunks in answer n.
- **Answer_{m}**: Possible answer sentences (`m` from 1 to 8).
- **Answer_label_{m}**: "Correct" or error type (e.g., `N1_alter`, `coordination`).
- **Answer_value_{m}**: Boolean indicating whether the option is correct or not.
- **Answer_template_{m}**: Chunk pattern of the sentence.
- **Answer_chunks_{m}**: The list of chunks in answer m.


The dataset comes pre-split into train and test sets, and includes preprocessed json files for use with our code at [[https://github.com/CLCL-Geneva/BLM-SNFDisentangling.]]


---

### Task Structure

The task follows a **multiple-choice format**, where:

- **Context**: A sequence of sentences (7 sentences) is given as the input.
- **Answer** set: A list of options is provided, where one is the correct continuation of the context, and others are distractors.
- **Objective**: The goal is to predict the correct next sentence by selecting from the answer set.


### Evaluation

Metrics commonly used for evaluation include **accuracy**, **precision**, **recall**, and **F1-score**.

Error analysis can be performed based on the **Answer_labels**, which indicate the types of errors corresponding to each of the incorrect options in the answer set.

---

## Citation
If you use this dataset in your research, please cite the corresponding paper:

```bibtex
@inproceedings{mulilingual-blm-2024,
  title={Exploring syntactic information in sentence embeddings through multilingual subject-verb agreement},
  author={Vivi Nastase, Chunyang Jiang, Giuseppe Samo, Paola Merlo},
  booktitle={CLiC-it 2024: Tenth Italian Conference on Computational Linguistics},
  year={2024},
}
```


